@@ -8,6 +8,7 @@ use strict;
 use warnings;
 
 require Exporter;
+require List::Util; # as it has the XS
 
 our @ISA = qw( Exporter );
 our @EXPORT_OK = qw(
@@ -15,11 +16,8 @@ our @EXPORT_OK = qw(
   subname set_subname
 );
 
-our $VERSION    = "1.52_001";
-$VERSION =~ tr/_//d;
-
-require List::Util; # as it has the XS
-List::Util->VERSION( $VERSION ); # Ensure we got the right XS version (RT#100863)
+our $VERSION    = "1.40";
+$VERSION   = eval $VERSION;
 
 =head1 NAME
 
@@ -27,7 +25,7 @@ Sub::Util - A selection of utility subroutines for subs and CODE references
 
 =head1 SYNOPSIS
 
-    use Sub::Util qw( prototype set_prototype subname set_subname );
+    use Sub::Util qw( set_prototype subname set_subname );
 
 =head1 DESCRIPTION
 
@@ -49,8 +47,6 @@ that its popularity warrants inclusion in a core module, which this is.
 
     my $proto = prototype( $code )
 
-I<Since version 1.40.>
-
 Returns the prototype of the given C<$code> reference, if it has one, as a
 string. This is the same as the C<CORE::prototype> operator; it is included
 here simply for symmetry and completeness with the other functions.
@@ -95,16 +91,14 @@ I<Since version 1.40.>
 Returns the name of the given C<$code> reference, if it has one. Normal named
 subs will give a fully-qualified name consisting of the package and the
 localname separated by C<::>. Anonymous code references will give C<__ANON__>
-as the localname. If the package the code was compiled in has been deleted
-(e.g. using C<delete_package> from L<Symbol>), C<__ANON__> will be returned as
-the package name. If a name has been set using L</set_subname>, this name will be
-returned instead.
+as the localname. If a name has been set using L</set_subname>, this name will
+be returned instead.
 
 This function was inspired by C<sub_fullname> from L<Sub::Identify>. The
 remaining functions that C<Sub::Identify> implements can easily be emulated
 using regexp operations, such as
 
- sub get_code_info { return (subname $_[0]) =~ m/^(.+)::(.*?)$/ }
+ sub get_code_info { return (subname $_[0]) =~ m/^(.+)::(.+?)$/ }
  sub sub_name      { return (get_code_info $_[0])[0] }
  sub stash_name    { return (get_code_info $_[0])[1] }
 
